@@ -569,11 +569,15 @@ impl VGER {
                     (glyph.y + padding + glyph.height as f32) / scale,
                 ];
                 // println!("quad_bounds: {:?}", prim.quad_bounds);
+
+                // The extra +/- 1.0 offset ensures we cover the same
+                // number of pixels when rasterizing as the glyph
+                // in the texture.
                 prim.tex_bounds = [
                     rect.x as f32 - padding,
                     (rect.y + rect.height) as f32 + padding,
-                    (rect.x + rect.width) as f32 + padding,
-                    rect.y as f32 - padding,
+                    (rect.x + rect.width) as f32 + padding + 1.0,
+                    rect.y as f32 - padding - 1.0,
                 ];
                 prim.paint = paint.index as u32;
                 // println!("tex_bounds: {:?}", prim.tex_bounds);
